@@ -1,15 +1,16 @@
+from __future__ import print_function, division, absolute_import
 
-
-import sys
-if sys.version_info < (3,):
-    import exceptions
 import re
 
 
+#############################################
+# dbapi errors
+#############################################
 class Error(Exception):
     pass
 
 
+# noinspection PyShadowingBuiltins
 class Warning(Exception):
     pass
 
@@ -75,9 +76,9 @@ class QueryError(ProgrammingError):
     def __init__(self, error_response, sql):
         self.error_response = error_response
         self.sql = sql
-        super(QueryError, self).__init__("{0}, SQL: {1}".format(
-            error_response.error_message(), repr(self.one_line_sql()))
-        )
+        ProgrammingError.__init__(self,
+                                  "{0}, SQL: {1}".format(error_response.error_message(),
+                                                         repr(self.one_line_sql())))
 
     def one_line_sql(self):
         if self.sql:
@@ -137,6 +138,14 @@ class DuplicateObject(QueryError):
     pass
 
 
+class QueryCanceled(QueryError):
+    pass
+
+
+class ConnectionFailure(QueryError):
+    pass
+
+
 QUERY_ERROR_CLASSES = {
     b'55V03': LockFailure,
     b'53000': InsufficientResources,
@@ -148,5 +157,7 @@ QUERY_ERROR_CLASSES = {
     b'22V04': CopyRejected,
     b'42501': PermissionDenied,
     b'22007': InvalidDatetimeFormat,
-    b'42710': DuplicateObject
+    b'42710': DuplicateObject,
+    b'57014': QueryCanceled,
+    b'08006': ConnectionFailure
 }
