@@ -1,20 +1,24 @@
-
+from __future__ import print_function, division, absolute_import
 
 from struct import unpack, unpack_from
 
-from vertica_python.vertica.messages.message import BackendMessage
+from six.moves import range
+
+from ..message import BackendMessage
 
 
 class RowDescription(BackendMessage):
+    message_id = b'T'
 
     def __init__(self, data):
-
+        BackendMessage.__init__(self)
         self.fields = []
         field_count = unpack('!H', data[0:2])[0]
         pos = 2
 
         for i in range(field_count):
-            field_info = unpack_from("!{0}sxIHIHIH".format(data.find(b'\x00', pos) - pos), data, pos)
+            field_info = unpack_from("!{0}sxIHIHIH".format(data.find(b'\x00', pos) - pos), data,
+                                     pos)
             self.fields.append({
                 'name': field_info[0],
                 'table_oid': field_info[1],
@@ -28,4 +32,4 @@ class RowDescription(BackendMessage):
             pos += 19 + len(field_info[0])
 
 
-RowDescription._message_id(b'T')
+BackendMessage.register(RowDescription)
